==> libhildon-extras_0.9.6.tar.gz: libhildon-extras-0.9.6/hildon-extras/he-cell-renderer-toggle.h <==
/*
 * This file is a part of hildon-extras
 *
 * Copyright (C) 2010 Gabriel Schulhof <nix@go-nix.ca>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version. or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef _HE_CELL_RENDERER_TOGGLE_H_
#define _HE_CELL_RENDERER_TOGGLE_H_

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define HE_TYPE_CELL_RENDERER_TOGGLE (he_cell_renderer_toggle_get_type())
#define HE_CELL_RENDERER_TOGGLE(object)           (G_TYPE_CHECK_INSTANCE_CAST((object), HE_TYPE_CELL_RENDERER_TOGGLE, HeCellRendererToggle))
#define HE_CELL_RENDERER_TOGGLE_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass),     HE_TYPE_CELL_RENDERER_TOGGLE, HeCellRendererToggleClass))
#define HE_IS_CELL_RENDERER_TOGGLE(object)        (G_TYPE_CHECK_INSTANCE_TYPE((object), HE_TYPE_CELL_RENDERER_TOGGLE))
#define HE_IS_CELL_RENDERER_TOGGLE_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE((klass),     HE_TYPE_CELL_RENDERER_TOGGLE))
#define HE_CELL_RENDERER_TOGGLE_GET_CLASS(object) (G_TYPE_INSTANCE_GET_CLASS((object),  HE_TYPE_CELL_RENDERER_TOGGLE, HeCellRendererToggleClass))

typedef struct _HeCellRendererToggle      HeCellRendererToggle;
typedef struct _HeCellRendererToggleClass HeCellRendererToggleClass;

GType he_cell_renderer_toggle_get_type() G_GNUC_CONST;

G_END_DECLS

#endif /* !_HE_CELL_RENDERER_TOGGLE_H_ */

==> libhildon-extras_0.9.7.tar.gz: libhildon-extras-0.9.7/hildon-extras/he-cell-renderer-toggle.h <==
/*
 * This file is a part of hildon-extras
 *
 * Copyright (C) 2010 Gabriel Schulhof <nix@go-nix.ca>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version. or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef _HE_CELL_RENDERER_TOGGLE_H_
#define _HE_CELL_RENDERER_TOGGLE_H_

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define HE_TYPE_CELL_RENDERER_TOGGLE (he_cell_renderer_toggle_get_type())
#define HE_CELL_RENDERER_TOGGLE(object)           (G_TYPE_CHECK_INSTANCE_CAST((object), HE_TYPE_CELL_RENDERER_TOGGLE, HeCellRendererToggle))
#define HE_CELL_RENDERER_TOGGLE_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass),     HE_TYPE_CELL_RENDERER_TOGGLE, HeCellRendererToggleClass))
#define HE_IS_CELL_RENDERER_TOGGLE(object)        (G_TYPE_CHECK_INSTANCE_TYPE((object), HE_TYPE_CELL_RENDERER_TOGGLE))
#define HE_IS_CELL_RENDERER_TOGGLE_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE((klass),     HE_TYPE_CELL_RENDERER_TOGGLE))
#define HE_CELL_RENDERER_TOGGLE_GET_CLASS(object) (G_TYPE_INSTANCE_GET_CLASS((object),  HE_TYPE_CELL_RENDERER_TOGGLE, HeCellRendererToggleClass))

typedef struct _HeCellRendererToggle      HeCellRendererToggle;
typedef struct _HeCellRendererToggleClass HeCellRendererToggleClass;

struct _HeCellRendererToggle {
	GtkCellRendererToggle __parent_instance__;
};

struct _HeCellRendererToggleClass {
	GtkCellRendererToggleClass __parent_class__;

	gboolean have_pbs;
	GdkPixbuf *pb_CheckButtonChecked;
	GdkPixbuf *pb_CheckButtonCheckedDisabled;
	GdkPixbuf *pb_CheckButtonUnchecked;
	GdkPixbuf *pb_CheckButtonUncheckedDisabled;
};

GType he_cell_renderer_toggle_get_type() G_GNUC_CONST;
GtkCellRenderer *he_cell_renderer_toggle_new();

G_END_DECLS

#endif /* !_HE_CELL_RENDERER_TOGGLE_H_ */
